==> humhub-1.2.8.tar.gz: humhub-1.2.8/protected/humhub/modules/activity/messages/it/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => 'Sommario <strong>email</strong>',
  'Activities' => 'Attività',
  'Daily' => 'Giornaliero',
  'E-Mail Summaries' => 'Sommario email',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'I sommari email sono inviati per informarti riguardo le attività recenti nella tua rete.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'I sommari email sono inviati per informare gli utenti riguardo le attività recenti nella tua rete.',
  'Exclude spaces below from the mail summary' => 'Escludi i sottostanti space dal sommario email',
  'Hourly' => 'Orario',
  'Interval' => 'Intervallo',
  'Latest news' => 'Ultime notizie',
  'Never' => 'Mai',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'In questa pagina puoi configurare i contenuti e l\'intervallo di questi aggiornamenti via email.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'In questa pagina puoi definire le regole di default per i tuoi utenti. Queste impostazioni possono essere sovrascritte dagli utenti nella pagina delle impostazioni dell\'account.',
  'Only include spaces below to the mail summary' => 'Includi soltanto i sottostanti space dal sommario email',
  'Reset to defaults' => 'Reimposta valori originali',
  'Spaces' => 'Space',
  'Weekly' => 'Settimanale',
  'You will only receive an e-mail if there is something new.' => 'Riceverai una email soltanto in caso di nuovo contento',
  'Your daily summary' => 'Il tuo riepilogo giornaliero',
  'Your weekly summary' => 'Il tuo riepilogo settimanale',
);

==> humhub-1.3.3.tar.gz: humhub-1.3.3/protected/humhub/modules/activity/messages/it/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => 'Sommario <strong>email</strong>',
  'Activities' => 'Attività',
  'Daily' => 'Giornaliero',
  'E-Mail Summaries' => 'Sommario email',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'I sommari email sono inviati per informarti riguardo le attività recenti nella tua rete.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'I sommari email sono inviati per informare gli utenti riguardo le attività recenti nella tua rete.',
  'Exclude spaces below from the mail summary' => 'Escludi gli spazi sottostanti dal sommario email',
  'Hourly' => 'Orario',
  'Interval' => 'Intervallo',
  'Latest news' => 'Ultime notizie',
  'Never' => 'Mai',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'In questa pagina puoi configurare i contenuti e l\'intervallo di questi aggiornamenti via email.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'In questa pagina puoi definire le regole di default per i tuoi utenti. Queste impostazioni possono essere sovrascritte dagli utenti nella pagina delle impostazioni dell\'account.',
  'Only include spaces below to the mail summary' => 'Includi soltanto i sottostanti spazi dal sommario email',
  'Reset to defaults' => 'Reimposta valori originali',
  'Spaces' => 'Spazi',
  'Weekly' => 'Settimanale',
  'You will only receive an e-mail if there is something new.' => 'Riceverai una email soltanto in caso di nuovo contento',
  'Your daily summary' => 'Il tuo riepilogo giornaliero',
  'Your weekly summary' => 'Il tuo riepilogo settimanale',
);
